package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````B!L``#0```#4H0````0`!30`(``)
M`"@`'0`<``$``'`4D0``%)$``!21``#H````Z`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$`````````````````````D@```)(```4`````$```
M`0```*2=``"DK0``I*T``*0"``"X`@``!@`````0```"````K)T``*RM``"L
MK0``(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DI)T`
M`*2M``"DK0``7`(``%P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`,EE+2SK@S*=$L:\LMF!1=#J7D&L$
M````$`````$```!'3E4```````0````#`````````&$```!K````````````
M``!9````00``````````````"````````````````````#D`````````2@``
M`#@```!D`````````"L```!0````40```#(```!A````9P````,````O````
M```````````C````1@```"T``````````````%(```!)````-@```$T```!>
M````:@```"$````'````"0`````````8`````````#\```!B````3P```#,`
M````````3````&,````U````#0```#H``````````````%H````Q````2```
M`$4````J````````````````````/0```$,````````````````````6````
M#P`````````^````(@```"<```````````````H```!'````-P```#L```!4
M`````````"X```!I````0`````````````````````````!5`````````$(`
M``!7````*`````8````D````2P``````````````````````````````````
M````````````````````````````````````````````````````````````
M$`````````!6````````````````````````````````````%```````````
M````6``````````<`````````&4```!H`````````!\``````````````!D`
M````````9@``````````````&P````X````@````)@````0````,````'@``
M`"P``````````````!T```!.``````````````!3````)0```%P````:````
M`````!<````+````````````````````6P```#`````\````$P```$0```!=
M````````````````````````````````````!0```````````````````#0`
M```````````````````1````````````````````*0```!4`````````$@``
M``````````````````````!?````````````````````8```````````````
M$0```$T````(````"`````&0$`0E0`2`*(``!:"&4(2`@0`""R@$C#B`$D&*
M```(30```$X```!1````50```%8```!?````8````&$`````````8P```&0`
M``!E````9@```&<```!J```````````````!KS3H;L7?'\[>1RUK?YI\+L6;
MMM1DU'QV5#R4(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_+%COEWFZXY)\
M^J%L8)E/PYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````-`5`````````P`,````
M````L`````````,`&``3`@`````````````2````MP(`````````````$@``
M`&<``````````````!(```#(```````````````2````!0(`````````````
M$@```$\"`````````````!(```">`@`````````````2````?P``````````
M````$@```/("`````````````!(````!```````````````@````L@$`````
M````````$@```.D"`````````````!(````_`@`````````````2````,@,`
M````````````$@```$T!`````````````!(```#.`0`````````````2````
M$```````````````(````,\"`````````````!(````,`@`````````````2
M````O`(`````````````$@`````"`````````````!(```#!````````````
M```2````+```````````````(````+H``````````````!(```"E`0``````
M```````2````P0(`````````````$@```#$!`````````````!8````A`0``
M```````````2````!0,`````````````$@```!`!`````````````!(```#:
M`@`````````````2````V@``````````````$@```.\``````````````!(`
M``#6`0`````````````2`````@0`````````````$@```&(!````````````
M`!(```"Q```````````````1````.`(`````````````$@```#D#````````
M`````!$```#=`0`````````````2````J0(`````````````$@```/8`````
M`````````!(```"Y`0`````````````2````<`(`````````````$@```/@!
M`````````````!(```"7`@`````````````2````E@``````````````$@``
M`"H"`````````````!(```#``0`````````````2````_P``````````````
M$@```+D``````````````!(```!M```````````````2````6P(`````````
M````$@```)X!`````````````!(```"+`@`````````````2````1`$`````
M````````$@```*\``````````````!$```#Q`0`````````````1````%@,`
M````````````$0```-```````````````!(````C`P`````````````1````
MX0``````````````$@```*<``````````````!(````%`0`````````````2
M````B`$`````````````$@```)8!`````````````!(```!\`@``````````
M```2````1@``````````````$@```'$!`````````````!(```!;`0``````
M```````2````QP$`````````````$@```.P!`````````````!(````9`@``
M```````````2````6```````````````(@```%T$``!<L````````!``&0`+
M!```2$H``#P!```2``X`@@0``"!```!8!P``$@`.`%,```#`&```R`(``!(`
M#@""`P``/#(```0````2``X`H`,``'A'``#0`@``$@`.`#,$``!(L```````
M`!``&0"H!```0#(``)`"```2``X`:`0``$BP````````$``9`),#``#0-```
M,````!(`#@"V`P``\#L``*`````2``X`%P0``-1.```$````$0`0`$$$```0
M3```7`$``!(`#@!,!```R#```%@````2``X`5`0``%RP````````$``9`'T$
M``!<L````````!``&0"6!```Z#X``#@!```2``X`OP0``)`\``!T````$@`.
M`"8$````L````````!``&`#:`P```#4``*P!```2``X`CP0``$BP````````
M$``8`+4$``!$L```!````!$`&``L!```B!L````````2``X`=`0``(1+``",
M````$@`.`"@$````L````````"``&`#P`P``Q#X``"0````2``X`Q`,``"`Q
M```<`0``$@`.`.8#``!L30``3`$``!(`#@!<!```7+`````````0`!D`QP0`
M`*PV``!$!0``$@`.``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V-X85]F:6YA;&EZ90!A8F]R=`!?7W)E9VES=&5R7V%T
M9F]R:P!?7V%E86)I7W5N=VEN9%]C<'!?<'(P`%]?<W1A8VM?8VAK7V9A:6P`
M<W1R;F-M<`!?7V5N=FER;VX`;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D
M9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M
M9&ER`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!B;V]T7T1Y;F%,;V%D
M97(`4$Q?8W5R<F5N=%]C;VYT97AT`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`
M;65M8VAR`%!E<FQ?<W9?<V5T<'9N`%]?865A8FE?=6YW:6YD7V-P<%]P<C$`
M7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R
M8VAR`'-T<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`;65M8W!Y`%]?=F9P
M<FEN=&9?8VAK`&5X:70`<W1D97)R`&QS965K-C0`<F5A9`!M96UC;7``9V5T
M=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H:P!O<&5N
M-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E
M<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U
M;@!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U
M;F1U;7``4$Q?;65M;W)Y7W=R87``;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`;&EB
M9V-C7W,N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U])
M;G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T
M85]S=&%R=`!?7V)S<U]S=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N
M9%]?`%]?8G-S7V5N9%]?`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'
M0T-?,RXU`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U
M+C0P+C(O87)M=C9L+6QI;G5X+71H<F5A9"UM=6QT:2TV-&EN="]#3U)%````
M```````"``$``@`"``(``0`!``,``0`!``(``0`!``(``0`"``$``0`"``(`
M`@`"``$`!``"``$``0`!``$``0`!``(``@`"``(``0`"``(`!0`"``$``@`"
M``$``@`"``(``@`"``(`!``"``$``@`!``(``@`"``$``@`!``(``@`!``(`
M`@`!``8``P`"``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`8`,``!``
M```@````%&EI#0``!0#4!`````````$``0!T`P``$````"````!5)GD+```#
M`-X$`````````0`#`%8#```0`````````+21E@8```8`Y@0``!````"SD98&
M```$`/$$```0````%&EI#0```@#4!````````*2M```7````J*T``!<```#\
MKP``%P````2P```7````%+```!<````8L```%P```""P```7````)+```!<`
M```HL```%P```"RP```7````,+```!<````XL```%P```#RP```7````1+``
M`!<```#(KP``%0L``,RO```5#```T*\``!43``#4KP``%1D``-BO```3'0``
MW*\``!4>``#@KP``%1\``.2O```5)P``Z*\``!4I``#LKP``%3P``/"O```5
M/0``]*\``!4_``#XKP``%4P``-BN```6`P``W*X``!8$``#@K@``%@4``.2N
M```6!@``Z*X``!8'``#LK@``%@@``/"N```6"0``]*X``!8,``#XK@``%@T`
M`/RN```6#@```*\``!8/```$KP``%A````BO```6$0``#*\``!82```0KP``
M%A0``!2O```6%0``&*\``!86```<KP``%A<``""O```6&```)*\``!8:```H
MKP``%AL``"RO```6'```,*\``!8@```TKP``%B$``#BO```6(@``/*\``!8C
M``!`KP``%B0``$2O```6)0``2*\``!8F``!,KP``%B@``%"O```6*@``5*\`
M`!8K``!8KP``%BP``%RO```6+0``8*\``!8N``!DKP``%B\``&BO```6,```
M;*\``!8Q``!PKP``%C(``'2O```6,P``>*\``!8T``!\KP``%C4``("O```6
M-@``A*\``!8W``"(KP``%C@``(RO```6.0``D*\``!8Z``"4KP``%CX``)BO
M```60```G*\``!9!``"@KP``%D(``*2O```60P``J*\``!9$``"LKP``%D4`
M`+"O```61@``M*\``!9(``"XKP``%DD``+RO```62@``P*\``!9+``#$KP``
M%DP```A`+>E\`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7@F````,:/X@G*C.+@
M^+SE`,:/X@G*C.+8^+SE`,:/X@G*C.+0^+SE`,:/X@G*C.+(^+SE`,:/X@G*
MC.+`^+SE`,:/X@G*C.*X^+SE`,:/X@G*C.*P^+SE`,:/X@G*C.*H^+SE`,:/
MX@G*C.*@^+SE`,:/X@G*C.*8^+SE`,:/X@G*C.*0^+SE`,:/X@G*C.*(^+SE
M`,:/X@G*C.*`^+SE`,:/X@G*C.)X^+SE`,:/X@G*C.)P^+SE`,:/X@G*C.)H
M^+SE`,:/X@G*C.)@^+SE`,:/X@G*C.)8^+SE`,:/X@G*C.)0^+SE`,:/X@G*
MC.)(^+SE`,:/X@G*C.)`^+SE`,:/X@G*C.(X^+SE`,:/X@G*C.(P^+SE`,:/
MX@G*C.(H^+SE`,:/X@G*C.(@^+SE`,:/X@G*C.(8^+SE`,:/X@G*C.(0^+SE
M`,:/X@G*C.((^+SE`,:/X@G*C.(`^+SE`,:/X@G*C.+X][SE`,:/X@G*C.+P
M][SE`,:/X@G*C.+H][SE`,:/X@G*C.+@][SE`,:/X@G*C.+8][SE`,:/X@G*
MC.+0][SE`,:/X@G*C.+(][SE`,:/X@G*C.+`][SE`,:/X@G*C.*X][SE`,:/
MX@G*C.*P][SE`,:/X@G*C.*H][SE`,:/X@G*C.*@][SE`,:/X@G*C.*8][SE
M`,:/X@G*C.*0][SE`,:/X@G*C.*(][SE`,:/X@G*C.*`][SE`,:/X@G*C.)X
M][SE`,:/X@G*C.)P][SE`,:/X@G*C.)H][SE`,:/X@G*C.)@][SE`,:/X@G*
MC.)8][SE`,:/X@G*C.)0][SE`,:/X@G*C.)(][SE`,:/X@G*C.)`][SE`,:/
MX@G*C.(X][SE`,:/X@G*C.(P][SE`,:/X@G*C.(H][SE`,:/X@G*C.(@][SE
M`,:/X@G*C.(8][SE`,:/X@G*C.(0][SE`,:/X@G*C.((][SE`<J@XW!`+>D,
MP$W@R`^,Y5C"G^4HT$WB5#*?Y1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-XA0@
MC>(<`(WB-%*?Y0`PD^4D,(WE`#"@X];__^LD(I_E!5"/X`(@E><<,I_E#""-
MY0,PE><"$*#A`P"@X1`PC>5?#0#K!#*?Y0,PE><`0-/E``!4XT\```IP+QWN
M\#&?Y1P`G>4#,)_G`T"`X@,@DN<$`(#BSC/2Y0<!<.,#,(/CSC/"Y6```(H`
M`:#AH?__ZP`PH.&\(9_E&!"=Y0(@C^``8)+EL,&?Y;!1G^6PX9_E'""=Y0``
MD>4,P(_@!5"/X`[@C^`!`%+C84"#Z`0PC.54``#:!`!!X@S`@^("`8#@!."Q
MY0$`4.$$X*SE^___&@/`@N(`X*#C:%&?Y6@1G^4%4(_@#`"5Y0SA@^<$(*#A
M`1"/X`#@C>4)___K``!0XRD```I$49_E(&"-X@50C^`,`)7E3?__ZP!`H.$P
M`9_E!A"@X0``C^#0`P#K``!0XR````H<,9_E`S"/X`P`D^7H_O_K(___ZPPA
MG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB<("]
MZ`'__^O<()_E``!0XP(@C^`,`(+E'P``"A;__^MP+QWNQ#"?Y0,PG^<#,)+G
M=D;#Y:/__^H,`)7EY/[_Z]+__^H(`)7E``!0XP$```K:"P#KV?__ZI0`G^4&
M$*#A``"/X*0#`.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)7G``"/X`,0
MH.$,,(WE-?__ZP3`H..P___J`0"@XUO__^L>___KW)4``!P!``"PE0``_```
M`!0!```D`0``>)8``*R6``"8E@``T#@``-`X``!0E@``C!(``"26``#L-0``
M^)4``&"4``"LE0``()4``-@T```H`0``M#8```"PH.,`X*#C!!"=Y`T@H.$$
M("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN<M___KD/[_ZPB3
M```P`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!EO[_ZO"2`````0``+`"?
MY2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!
M$_\OX4B4``!$E```O)(```0!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.%#
M$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A!)0```"4
M``!LD@``"`$``%@PG^58()_E`S"/X``PT^4"((_@``!3XQ[_+Q$!RJ#C$$`M
MZ0S`3>#X#XSE-#"?Y0,PDN<``%/C`@``"B@PG^4#`)_G^?[_Z\?__^L!(*#C
M&#"?Y0,PC^``(,/E$("]Z+23```PD@``+`$``#B3``!HDP``S?__Z@`````!
MRJ#C\$\MZ0S`3>!`#8SE4"R?Y5`\G^4"((_@`S"2YZ??3>(`$*#A$,"-X@`P
MD^64,HWE`#"@XPP@H.$`0*#C0`"`XH!0@>)`0!#I+C2@X?\\`^(N/(/A#G2@
MX0X\@^'_>`?B"`"`XC;OO^8',(/A``!5X0#@@N4$0(+E"#""Y0Q`@N40((+B
M[O__&H(_C.(<0)WE>,"=Y00PC>6(,)WE&%"-X@@0C>4%`*#A#+"@X0,0H.%\
M()WE&*"=Y8"`G>6$<)WEC."=Y1!@G>44D)WE`$"-Y0Q0C>4!``#J!:"@X0!`
MC>4`0*#C`3"@X3S`D.4X$)#E"%"PY71`@.4$0)#E!1`AX`L0(>`$P"S@!A`A
MX`+`+.`)P"S@"+"@X0.`H.&A/Z#AC#"#X0$0D>`#$('A!#"=Y0<@H.$#`%#A
M#G"@X0I@H.$`X*#C`)"=Y7`0@.7A__\:"!"=Y0Q0G>4`D)'E"#N?Y0@@%>4@
MX)'EJ6V@X0$(D>D0@)'E&*"1Y0,@DN"`8H;A#B"2X(EBAN$,P)'E`F"6X`H@
M*.`K0:#A"R`"X`H@(N`,3X3A`F"6X`M/A.$8()WE*<&@X0#/C.$$`"C@`R"2
MX`D``.`*()+@"``@X`G/C.$``)+@"""5Y0S@).`#()+@!N`.X`3@+N`(()+@
MY@V`X`X@DN#@[8+@$""5Y0,@DN`$()+@9D$LX`!`!.`,0"3@!""2X!A`E>5@
M`:#A`T"4X`S`E.!F02#@#D`$X&9!).#N+8+@!,"<X.)-C.`@P)7E`\"<X&;!
MC.!N82#@`F`&X`!@)N`&P)S@*&"5Y6(AH.$#8);@``"6X&YA(N`$8`;@;F$F
MX.3-C.`&`)#@[&V`X#``E>4#`)#@;@&`X&3A(N`,X`[@`N`NX`X`D.`XX)7E
M;,&@X0/@GN`"()[@9.$LX`;@#N!DX2[@Y@V`X`X@DN#@[8+@0""5Y0,@DN!D
M(8+@9D$LX`!`!.`,0"3@!""2X$A`E>5@`:#A`T"4X`S`E.!F02#@#D`$X&9!
M).#N+8+@!,"<X.)-C.!0P)7E`\"<X&;!C.!N82#@`F`&X`!@)N`&P)S@6&"5
MY6(AH.$#8);@``"6X&YA(N`$8`;@;F$FX.3-C.`&`)#@[&V`X&``E>4#`)#@
M;@&`X&3A(N`,X`[@`N`NX`X`D.!HX)7E;,&@X0/@GN`"()[@9.$LX`;@#N!D
MX2[@Y@V`X`X@DN#@[8+@<""5Y0,@DN!D(8+@9D$LX`!`!.`,0"3@!""2X'A`
ME>5@`:#A`T"4X`S`E.!F02#@#D`$X&9!).#N+8+@!,"<X.)-C."`P)7E`\"<
MX&;!C.!N82#@`F`&X`!@)N`&P)S@Y&V,X(C`E>5B(:#A`\"<X```G.!NP2+@
M!,`,X&[!+.`,`)#@YLV`X)``E>4#,)#@9`$BX`8``.`"`"#@;C&#X``PD^#L
M?8/@F`"5Y2PXG^5F8:#A`P"0X*#@E>4"()#@9`$FX`P`(.``()+@`P">X&0!
M@.#G[8+@J$"5Y6PA)N`'("+@`@"0X&<AH.$#0)3@L'"5Y09`E.!L82+@#F`F
MX.X-@.`&0)3@`V"7X&QAAN"X<)7EX,V$X&Y!(N``0"3@!&"6X&`!H.$#0)?@
M`D"4X,!PE>7L+8;@;F$@X`Q@)N`&8)3@`T"7X&Y!A.#(<)7E;.$@X`+@+N#B
M;8;@#D"4X&(AH.$#X)?@``">X-!PE>5LX2+@!N`NX`[@D.`#`)?@YDV$X-AP
ME>5L`8#@9L$BX`3`+.#D[8[@#`"0X&1!H.$#P)?@`B"<X.!PE>5FP23@#L`L
MX`S`DN`#()?@[@V`X.APE>5F(8+@;F$DX`!@)N#@S8S@!B"2X&`!H.$#8)?@
M!&"6X/!PE>5N02#@#$`DX`1`EN`#8)?@["V"X&YAAN#X4)7E;.$@X`+@+N#B
M383@#N"6X&(AH.$#4)7@`%"5X!AAG>5L`2+@!``@X.3MCN```)7@`V"6X.Y=
M@.!LP8;@9`$BX"!AG>4.`"#@;N&@X2AQG>4``)S@`V"6X&3!+N`"();@!<`L
MX.4-@.`,P)+@`R"7X.!MC.!D(8+@9<$NX#!!G>4`P"S@#,"2X&`!H.$#0)3@
MYBV,X`[@E.!EP2#@.$&=Y0;`+.`,P)[@`^"4X&7ACN!F02#@0%&=Y0)`).#B
MS8S@!.">X&(AH.$#4)7@``"5X&9!(N!(49WE#$`DX`1`D.`#`)7@[.V.X/`U
MG^50<9WE9@&`X&QA(N!N4:#A#F`FX.Y-A.`&8)#@;.&%X0,`E^`"`)#@6'&=
MY>0MAN`$X`[@;&$%X`;@CN$.X)#@`W"7X&0!A>%D807@;,&'X`(``.!@<9WE
M!@"`X>+MCN`,`)#@8B&@X0/`E^`%P)S@9%&"X61A`N!H<9WE#E`%X`90A>'N
M#8#@#%"5X`-PE^!NP8+A;F$"X&1!A^``P`S@<'&=Y0;`C.'@787@!$"<X&`!
MH.$#P)?@`L"<X.4MA.!N08#A;F$`X'AQG>4%0`3@!D"$X0Q`E.`#<)?@9<&`
MX65A`.!NX8?@`L`,X(!QG>4&P(SAXDV$X`[@G.!B(:#A`\"7X`#`G.#D#8[@
M9>&"X65A`N"(<9WE!.`.X`;@CN$,X)[@`W"7X&3!@N%D80+@95&'X`#`#."0
M<9WE!L",X>#MCN`%4)S@8`&@X0/`E^`"P)S@[BV%X&11@.%D80#@F'&=Y0Y0
M!>`&4(7A#%"5X`-PE^!NP8#A;F$`X&1!A^`"P`S@H'&=Y0;`C.'B787@!$"<
MX&(AH.$#P)?@`,"<X.4-A.!N08+A;F$"X*AQG>4%0`3@!D"$X0Q`E.`#<)?@
M9<&"X65A`N!NX8?@`,`,X+!QG>4&P(SAX$V$X`[@G.!@`:#A`\"7X`+`G.#D
M+8[@9>&`X65A`."X<9WE!.`.X`;@CN$,X)[@`W"7X&3!@.%D80#@95&'X`+`
M#.#`<9WE!L",X>+MCN`%4)S@8B&@X0/`E^``P)S@[@V%X&11@N%D80+@#E`%
MX`90A>$,4)7@;L&"X6YA`N``P`S@!L",X0!@H./(<9WEX%V%X`-PE^!D08?@
MT'&=Y6`!H.$$0)S@`\"7X`+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@@>4<
M8('E;F$`X-AQG>4&0(3A#$"4X&7!@.$#<)?@96$`X`+`#.!NX8?@!L",X>!Q
MG>7B383@#L"<X&(AH.'D[8S@`W"7X&7!@N%E80+@``"7X`3`#.#H<9WE!L",
MX0#`G.`#<)?@9`&"X>@RG^5D80+@95&'X`X``.#P<9WE!@"`X>[-C.`%`)#@
M;N&@X0-0E^`"4)7@^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!AN!L
M(2[@`&*=Y0`@(N`"()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4X`-`
MEN#E+8+@$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@&&*=
MY64!(N`.`"#@[LV,X```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.```)3@
M;,&@X0-`EN`"0)3@*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[AAN!E
M(2S@,&*=Y0`@(N`"()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"X`S`
MGN`#X);@9>&.X$!BG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@2&*=
MY60!(N`%`"#@Y<V,X```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.```)[@
M;,&@X0/@EN`"X)[@6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!BG>7@
M78+@9"$LX``@(N`"()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"X`S`
MGN`#X);@9.&.X'!BG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@>&*=
MY64!(N`$`"#@``">X`/@EN#DS8S@9>&.X&1A(N"`4IWE[`V`X`Q@)N!LP:#A
M!N">X`-0E>!D82S@`&`FX`(@E>`&()+@`&"@XXA2G>7@[8[@`S"5X&"ABN`)
M,)/@8`$LX`X`(.!D,8/@`#"3X.XM@N#B/8/@(`"1Y0L@DN!N@8C@&*"!Y1"`
M@>4`,('E"""!Y4P@G^4`P)S@,#"?Y0(@C^`@P('E)&"!Y0,PDN<`()/EE#*=
MY0(@,^``,*#C`0``&J??C>+PC[WHD/O_ZZR1```<`0``F7F"6J'KV6[<O!N/
MUL%BRHR%```!RJ#C\$<MZ0S`3>#@#XSEO#"?Y;P@G^4#,(_@`C"3YP"0D^4`
M`%GC)P``"@!0T.4`@*#A``!5XST`51,!<*#A`5"@$P!0H`,1```:`$"9Y0``
M5.,,```*"6"@X04@H.$($*#A!`"@X9+[_^L``%#C`@``&@4PU.<]`%/C"P``
M"@1`MN4``%3C\___&@0`H.'PA[WH`%"@X0$P]>4``%/C/0!3$_O__QH(4$7@
MYO__Z@E@1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@)0*#A[?__ZBB%```8
M`0```<J@XQ!`+>D,P$W@B`^,Y8P@G^6,,)_E`B"/X'#03>(#,)+G#1"@X0`P
MD^5L,(WE`#"@XP!`H.%/^__K``!0XP``H!,$```:$#"=Y0\Z`^(*"E/C`0E3
M$PH```I(()_E0#"?Y0(@C^`#,)+G`""3Y6PPG>4"(#/@`#"@XP<``!IPT(WB
M$("]Z`(0H.,$`*#A]/K_ZQ`/;^&@`J#A[O__ZBG[_^M,A```'`$```"$```!
MRJ#C\$`MZ0S`3>!P#XSE8"&?Y6`QG^4"((_@`S"2YWS03>(`4%#B`#"3Y70P
MC>4`,*#C`@``"@`PU>4``%/C"@``&C0AG^4L,9_E`B"/X`,PDN<`()/E=#"=
MY0(@,^``,*#C0@``&GS0C>+P@+WHH_K_ZP!@4.+Q__\*!@"@X2/[_^L``%#C
M*P``"A,PT.430(#B+@!3XP(``!H!,-3E``!3X_3__PH3,-#E+@!3XR8```H%
M`*#AT/K_ZP!PH.$$`*#AS?K_ZP!PA^`"<(?B!P"@X>WZ_^L$0(WE`$"@X9PP
MG^4'(*#A`A"@XP,PC^``4(WE"?O_ZP0`H.$($(WBK_K_ZP$`<.,$`*#A`P``
M"A@PG>4/.@/B`0E3XQ(```JY^O_K!`"@X9SZ_^L&`*#A]_K_ZP``4./3__\:
M!@"@X<;Z_^L%`*#AW/K_Z[S__^H!,-3E+@!3X]7__QH",-3E``!3X\3__PK1
M___JH___Z^O__^K(^O_KG(,``!P!``!H@P``9",```'*H.,00"WI#,!-X.@/
MC.5P3QWN;!"?Y6PPG^4!$(_@`S"1YQ#03>)@`)_E##"-Y0,@H.$``)_G5#"?
MY500G^4``)3G`S"/X`$0C^#7^O_K`,"@XT``G^5`,)_E``"?YSP@G^4\$)_E
M`S"/X```E.<"((_@"!"-Z`$0C^!W^O_K$-"-XA"`O>@0@@``$`$```2#``!$
M8P``B"(``-R"``!\)0``:!H``'0B```!RJ#C\$$MZ0S`3>```(SE(``,Y0%P
MH.'\$)_E`=I-XO@PG^4(T$WB`1"/X`,PD><`8*#A`0J-X@0`@.(`,)/E`#"`
MY0`PH./4`)_E!("-X@@0H.',()_E``"/X)SZ_^L`0%#B!@``V@$P1.(#P(W@
M!"#<Y0``4N,7```:``!3XQ0``!IP#QWNG#"?Y0<@H.$#,)_G!A"@X0,`D.<F
M^O_KB""?Y70PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XQ(`
M`!H!VHWB"-"-XO"!O>@#0*#A!""@X2\0H.,(`*#AE/K_ZP``4./C__\*<,\=
M[C0`G^4$,*#A``"?YP@@H.$&$*#A``"<YSGZ_^OA___J4OK_ZUB!```<`0``
M`"(``/\/``#\@0``V(```(R!```!RJ#C\$\MZ0S`3>#0#XSE`4"@X1@BG^48
M,I_E`B"/X`,PDN<,T$WB`#"3Y00PC>4`,*#C`##1Y0!0H.$]`%/C`4"!`@0`
MH.$1^O_K#1"@X0!@H.$%`*#AJO[_Z]AQG^4`D%#B!W"/X$````H(^O_K``!6
MX3<``)K`,9_E`("=Y0-PE^<(@:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*
M!3"@X0$@\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`@.``8)?E%OK_ZP``4.,(
M`(;G%0``"@4`H.$`,)?E"!"3YP$PT.0]`%/C``!3$P`PP>4&```*`2"!X@$P
MT.0"$*#A``!3XST`4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0``%/C`3#B
MY?O__QH0(9_E`#&?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XS<``!H,T(WB
M\(^]Z`&02>(!,-3D``!3XP$PZ>7[__\:[O__ZL@PG^4#<)?G`("7Y0`PF.4`
M`%/C)@``"@@PH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!L:#AF#"?Y0,P
MC^``()/E``!2XQ```!H!(*#C"P"@X0`@@^75^?_K`*!0XM7__PH($*#A"8&@
MX0LPH.$((*#A^_G_ZP"@A^4`,*#C`)"-Y0&0B>(),8KGH?__Z@L0H.$(`*#A
M]?G_ZP``4.,`H*#A``"'Y</__PH)@:#A\?__Z@.0H.$(L*#CW?__ZK[Y_^LL
M@```'`$``.1_```8`0``%'\``!R````\$)_E/#"?Y0$0C^`#,)'G<,\=[@,@
MH.$(T$WB*`"?Y00PC>4``)_G(#"?Y2`0G^4``)SG`S"/X`$0C^`(T(WBSOG_
MZO1]```0`0``Y'X``"1?``!H'@```<J@X_!`+>D,P$W@``",Y0'*3.(``(SE
M,``,Y>`@G^4"VDWBW#"?Y1S03>("((_@`S"2YP(:C>(4$('B`#"3Y0`P@>4`
M,*#CI/G_Z[C`G^6X,)_E`4J-X@S`C^`00(3B`1"-Z`(0H.,$`*#AH""?Y0,P
MC^`,8(WBI/G_ZP0`H.$!*J#C!A"@X9KY_^L`0%#B`%"@LPH``+H!<(3B!P"@
MX7;Y_^L`4%#B!0``"@<PH.$&$*#A!""@X4#Y_^L`,*#C!##%YTP@G^4X,)_E
M`B"/X`(:C>(#,)+G%!"!X@`@D^4`,)'E`B`SX``PH.,#```:!0"@X0+:C>(<
MT(WB\("]Z&'Y_^MX?0``'`$``$`>```<'@```1```-A\``"W___J`<J@X_!/
M+>D,P$W@``",Y:@`#.5$PI_E0MU-XD`BG^4$T$WB#,"/X`!@H.$T`I_E`B"<
MYT$]C>(0@(WB`4"@X0``C^`($*#A/#"#X@`@DN4`((/E`""@X[G]_^LO$*#C
M`%"@X08`H.'H^/_K``!0XQ(```KP`9_E!A"@X0``C^#M_O_K!@"@X>`AG^70
M,9_E`B"/X$$=C>(#,)+G/!"!X@`@D^4`,)'E`B`SX``PH.-I```:0MV-X@30
MC>+PC[WH!`"@X1SY_^ND$9_E`1"/X"OY_^L`0%#BY?__"@`PU.60D9_E@*"-
MX@``4^,)D(_@!'!*XCL```H``%7C!```"@00H.$%`*#A4/G_ZP``4.,K```*
M!`"@X>SX_^L!,$#B`S"$X`,`5.$`L*#A`,"@,P`PA#`!$(0R`P``.@@``.H#
M`%'A`,##Y0(```H!('/E+P!2X_G__PH$`*#AV_C_ZP"PH.$&`*#AV/C_ZPL`
M@.`!`(#B`0I0X[W__RKX`)_E"3"@X0``C^`!*J#C`A"@XT$`C>D`0(WE!P"@
MX1/Y_^L($*#A!P"@X;GX_^L``%#C`P``&F`P&N4/.@/B`@E3XQ4```JT$)_E
M``"@XP$0C^#K^/_K`$!0XJ7__PH`,-3E``!3X\/__QH``%7C%@``"@`PU>4N
M`%/C`P``"H!`G^4!L*#C!$"/X-7__^H!,-7E``!3X^K__PKW___J`1"@XP<`
MH.&7^/_K``!0X^3__QI0`)_E!Q"@X0``C^!^_O_K!P"@X;SX_^N.___J.$"?
MY0&PH.,$0(_@P?__ZL+X_^M@?```'`$``$`=```0'0``]'L``-`<``"T'```
M)!P``-`;``!X&P``5!L``"@;```!RJ#C$$`MZ0S`3>#X#XSE+Q"@XP!`H.%G
M^/_K``!0XP%`@!($`*#A$$"]Z)[X_^H!RJ#C<$`MZ0S`3>```(SE&``,Y70A
MG^4!VDWB<#&?Y0C03>("((_@`1J-X@,PDN<`8%#B!!"!X@`PD^4`,('E`#"@
MXR\```H`,-;E``!3XRP```IM^/_K`2"`X@$*4N,`0*#A.```B@10C>(&$*#A
M!0"@X6OX_^L!,$3B`S"%X`4`4^$'``":`!"@XP(``.H#`%7A`1##Y0(```H!
M(%/D+P!2X_G__PHO$*#C!0"@X37X_^L``%#C)0``"@4`4.$`,*"#`##`A04`
MH.%J^/_KP""?Y;@PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@
MXR,``!H!VHWB"-"-XG"`O>B,()_E@#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E
M`#"1Y0(@,^``,*#C%0``&F0`G^4``(_@`=J-X@C0C>)P0+WH2_C_Z@``H./>
M___J2""?Y30PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XP(`
M`!H@`)_E``"/X.O__^I&^/_KH'D``!P!``#L>```M'@``(09``!H>```.!D`
M``'*H.-P0"WI#,!-X.@/C.7$))_EQ#2?Y0(@C^#`5)_E`S"2Y[QDG^4(T$WB
M!5"/X``PD^4$,(WE`#"@XP9@C^`-0*#A!!"@X08`H.&A_/_K``!0XPX```J,
M-)_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``
M4N,$((/D^___&NO__^I49)_E!F"/X`00H.$&`*#AB_S_ZP``4.,.```*-#2?
MY0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C
M!""#Y/O__QKK___J`&2?Y09@C^`$$*#A!@"@X77\_^L``%#C#@``"MPSG^4`
M$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@
M@^3[__\:Z___ZJQCG^4&8(_@!!"@X08`H.%?_/_K``!0XPX```J$,Y_E`!"=
MY0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D
M^___&NO__^I88Y_E!F"/X`00H.$&`*#A2?S_ZP``4.,.```*+#.?Y0`0G>4#
M,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O_
M_QKK___J!&.?Y09@C^`$$*#A!@"@X3/\_^L``%#C#@``"M0RG^4`$)WE`S"5
MYP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:
MZ___ZK!BG^4&8(_@!!"@X08`H.$=_/_K``!0XPX```I\,I_E`!"=Y0,PE><`
M()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO_
M_^I<8I_E!F"/X`00H.$&`*#A!_S_ZP``4.,.```*)#*?Y0`0G>4#,)7G`""3
MY0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J
M"&*?Y09@C^`$$*#A!@"@X?'[_^L``%#C#@``"LPQG^4`$)WE`S"5YP`@D^4!
M,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZK1A
MG^4&8(_@!!"@X08`H.';^__K``!0XPX```IT,9_E`!"=Y0,PE><`()/E`3&"
MX`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I@89_E
M!F"/X`00H.$&`*#AQ?O_ZP``4.,.```*'#&?Y0`0G>4#,)7G`""3Y0$Q@N`$
M`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J#`&?Y000
MH.$``(_@L/O_ZP`04.("```*^`"?Y0``C^#I_/_K\`"?Y000H.$``(_@I_O_
MZP`04.("```*W`"?Y0``C^#@_/_KU`"?Y000H.$``(_@GOO_ZP`04.(2```*
MP`"?Y0``C^#7_/_KN""?Y60PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,0
M```:F!"?Y9@`G^4!$(_@``"/X`C0C>)P0+WHQ_S_ZH0`G^4$$*#A``"/X(7[
M_^L`$%#BZ?__"G``G^4``(_@OOS_Z^7__^H(]__K`'@``!P!``#L=P``!!D`
M`!@!``"T&```9!@``!@8``#(%P``@!<``,06``#<%@``D!8``$06``!P%0``
MG!4``'`5``",%0``C!4``(@5``"L%```H',``&05``#(%```-!4``+@4```!
MRJ#C!.`MY0S`3>#P#XSE>""?Y7@PG^4"((_@=`"?Y0S03>(#,)+G#1"@X0``
MC^``,)/E!#"-Y0`PH.-4^__K``!0XP4```H``-#E``!0XS``4!,!`*`#``"@
M$P$`(.(T()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XP$``!H,T(WB
M!/"=Y,KV_^N\<@``'`$``!04``!L<@```<J@XP\`+>D$X"WE#,!-X/`/C.5(
M()_E2#"?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XS``G^4PP)_E%#"-X@``
MC^``,(WE#`"0YP(0H.,0()WE``"0Y9KV_^O_`*#CZ?;_ZQAR```<`0``]'$`
M`"`!````P*#C\$,MZ0'HH.,,P$W@#N!,X`'*3.(``(SE#@!<X?O__QHX``[E
M`A"@XW#AG^4!V$WB;,&?Y1S03>(.X(_@#,">YP%(C>(`(*#C`#"@XP#`G.44
MP(3E`,"@XP`0C>4`@*#AB?;_ZP%@4.(`<,'BQR^@X<<_)N`",%/@<S#_Y@(P
M(^`",%/@`B#"X`-@5N`"<,?@``!7XQ1`A.(V``"Z#%"-X@`0H.,&(*#A!S"@
MX0@`H.$`$(WE=/;_ZP$`<>,!`'`#,@``"@40H.$(`*#AU""?Y3?V_^L!`'#C
M*0``"@<`4.,?``":"`!`X@!`E>`<```JM)"?Y0F0C^`"``#J`4!$X@4`5.$6
M```Z"""@XPD0H.$$`*#A__7_ZP``4./V__\:!4!$X`8`E.#$'Z?@?""?Y6PP
MG^4"((_@`<B-X@,PDN<4P(SB`""3Y0`PG.4"(#/@`#"@XQ```!H!V(WB'-"-
MXO"#O>@!:%;B`'#'X@$`=^,!"'8#R?__&@``X.,`$*#AZ?__ZB@`G^4``(_@
M??__ZR``G^4``(_@>O__ZT#V_^N$<0``'`$```@``0`$<@``B'```#`2```4
M$@```<J@XQ!`+>D,P$W@^`^,Y?+U_^L5]O_K``!0XP``D!40@+WH`<J@X_!`
M+>D,P$W@T`^,Y0`AG^4`<9_E`#&?Y0(@C^`<T$WB`S"2YP=PC^``4*#A!P"@
MX1`0C>(`,)/E%#"-Y0`PH..4^O_K`$!0X@(```H`,-3E``!3XPX``!K`()_E
MN#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XR0``!H%$*#AG`"?Y0``C^`<
MT(WB\$"]Z+[[_^H%`*#AX?7_ZP!@H.$$`*#AWO7_ZP!@AN`"8(;B!@"@X?[U
M_^MH$)_E:#"?Y0$0C^`&(*#A"$"-Y0,PC^`$$(WE`%"-Y0(0H.,`0*#A%_;_
MZT0@G^4L,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``,*#C!!"@`0<`H`'=__\*
MZO7_Z\!O``"\$0``'`$``'AO``!<$0``,!```"@0``#L;@```<J@X_!/+>D,
MP$W@X`Z,Y;0FG^7\T$WB`B"/X+!`C>("X*#A!."@X:`6G^4@((WEG,:?Y9PF
MG^4!$(_@`B"1YPS`C^`,,(SB&&",XJ1PC>(`()+E]""-Y0`@H.,<`(WE!P"3
MZ`<`A^@/`+;H#P"NZ`,`EN@PP(SBF%"-X@,`CN@'`)SH!P"%Z$P&G^4H@(WB
M"!"@X0``C^`Q^O_K`&!0X@(```H`,-;E``!3XRD!`!IS]?_KEO7_ZP``4..(
M```*`&"0Y0``5N.%```*!@"@X8;U_^N`(*#A`;""X@L`H.&F]?_K`,#6Y0!0
MH.$``%SC"Y"@$20`C14D`0`*W*6?Y0J@C^`+(*#A"C"@X0(0H.,%`*#A`,"-
MY;SU_^L+`%GA"2"@(0L@H#$",$OB"Q!"X`'`]N4"$('B`C!#X`(`4>$!L(,@
M`K"#,```7.,"4(7BZ___&H@%G^4``(_@`@``Z@0`M.4``%#C#0``"@@0H.'[
M^?_K`%!0XOC__PH`,-7E``!3X_7__PHL^O_K``!0X_+__PH%`*#A;_7_ZP!`
M4.(-```:!$"7Y```5.,*```*`##4Y0``4^/4```*!`"@X1[Z_^L``%#C]?__
M"@0`H.%A]?_K`$!0XO'__PH$`*#A0O7_ZR1@G>4`4*#A!@"@X3[U_^L`4(7@
M`5N%X@10A>(%`*#A7?7_ZP!PH.'4-)_E!2"@X0,PC^`(,(WER#2?Y0(0H.,#
M,(_@!#"-Y;PTG^4,8(WE`S"/X`!`C>5S]?_K!QV@XP<`H.'@]/_K`0!PXP,`
M`!J+]?_K`,"0Y1$`7..P```:"!"@X0<`H.%2]?_K`$!0XC$```IT-)_E(""=
MY0(0H.,#()+G'#"=Y0``DN5@))_E`#"3Y0(@C^``<(WE//7_ZP!@H.-,))_E
M)#2?Y0(@C^`#,)+G`""3Y?0PG>4"(#/@`#"@X_L``!H&`*#A_-"-XO"/O>@?
M]?_K`&!0XHP``!H$`)7D``!0XPD```H($*#AFOG_ZP`P4.+X__\*`##3Y0``
M4^/R__\:!`"5Y```4./U__\:#0"@XQ?U_^L-D*#CU&.?Y5/`H.,`4*#A";"@
MX09@C^`D`(WE;O__ZC@PG>4/.@/B`0E3X\G__QI`8)WERO3_ZP``5N'%__\:
M.#"=Y8,[H.&C.Z#A!PU3X\#__QH%`*#A`/7_ZP!@H.%\`Y_E"!"@X0``C^!T
M^?_K`!!0XG\```H<,)WE``"3Y9[[_^L`H%#B>@``"@H`H.'.]/_K`P!0XP"0
MH.$,``":0!.?Y00`0.(``(K@`1"/X";U_^L``%#C!0``&@0`6>.E```*"9"*
MX`4P6>4O`%/CH0``"A`#G^4($*#A``"/X%?Y_^L``%#C`P``"@`PT.4P`%/C
M``!3$P0``!H*`*#A`!"@X\#T_^L`@%#B7```&M@2G^78`I_E`1"/X```C^"%
M^O_KY?3_Z\@RG^7((I_E`S"/X`0PC>7`,I_E`B"/X+RBG^6\DI_EO(*?Y0@`
MC>4,((WE`A"@XP4@H.$&`*#A`'"-Y0,PC^#@]/_K"J"/X`F0C^`(@(_@#@``
MZOGT_^L`,)#E$0!3XP\``!K+]/_K`,"@X0%`A.("$*#C"C"@X04@H.$&`*#A
M@!&-Z!"0C>4,0(WES?3_ZP<=H.,&`*#A.O3_ZP$`<./K__\*!P"@X6;T_^LT
M`I_E!A"@X0``C^!5^O_K!@"@X6[^_^ME___J`T"@X3#__^IT]/_K@""@X0&P
M@N+L_O_J(!"=Y<`AG^4<,)WE`B"1YP`PD^4``)+E["&?Y0(0H..`$(WH`B"/
MX)#T_^M2___J6O[_Z]0AG^5P,9_E`B"/X`,PDN<`()/E]#"=Y0(@,^``,*#C
M3@``&@8`H.'\T(WB\$^]Z'+T_^HD`(WE[O[_ZAPPG>4`H)/E@?__ZL[]_^L`
MH%'B`)"@X9[__[H`L*#C"B!0X@`PRN((`*#A`+"-Y6GT_^N0$(WB!B"@XP@`
MH.$<$(WE+O3_ZP8`4.,<$)WE-```&D@QG^60()WE`P!2X8S__QJT(-'A.#&?
MY0,`4N&(__\:,B!9X@`PRN((`*#A`+"-Y<A`C>)3]/_K*""@XP@`H.$$$*#A
M&?3_ZR@`4.,@```:`#&?Y0`1G^4#,(_@!#"-Y?@PG^4!$(_@#!"-Y04@H.$"
M$*#C!@"@X0A`C>4`<(WE`S"/X/"PS>5E]/_KF___ZAPPG>4$D)/E``!9XUG_
M_PH)`*#A%O3_ZP,`4.-5__^:K!"?Y00`0.(``(G@`1"/X&_T_^L``%#C":"@
M`4W__^HR]/_KC`"?Y0``C^!H_?_KC&X``&QN``"@;P``'`$```P/``#$#P``
M!`\``,0.``"D#0``F`X``"`!``"$#@``]&L``(@-``#H#0``K`T``!0,``!4
M#```U`L``'@+````#@``(`T``"@-``#,#0``-`L``*0*``"4"P``0&D```!#
M04-(10``A`D```P,```H"P``V`H``,0*```!RJ#C<$`MZ0S`3>#H#XSE6"*?
MY5@RG^4"((_@`S"2YPC03>(`,)/E!#"-Y0`PH.-P3QWN/#*?Y3P"G^4#,)_G
M#1"@X0-0E.<``(_@:##5Y0U@H.%I,,7E:_C_ZP``4.,"```*`##0Y3$`4^-E
M```*K_O_ZP0RG^4#,)_G`U"4Y_P1G^4%`*#A`S"@XP$@H.,!$(_@E?/_ZP!0
M4.(,```*$""5Y=PQG^4`$)+E`S"?Y]0AG^4#`)3G`B"/X)'S_^L0,)7E`!"3
MY0@PD>4!!1/C5P``&K01G^4#,*#C`1"?YP$@H.,!`)3GI!&?Y0$0C^!^\__K
M`%!0X@L```J4`9_E!A"@X0``C^`_^/_K$#"5Y0`@4.(`$)/E/@``"G@QG^4#
M,)_G`P"4YW;S_^ML,9_E;!&?Y0,PG^<!(*#C`U"4YP$0C^`%`*#A6?/_ZU0A
MG^4`$*#A`B"/X`4`H.%I\__K`""@XT`QG^5``9_E`S"?YP80H.$#,)3G``"/
MX&D@P^4A^/_K*%&?Y0``4.,%4(_@`$"@X0@`A>41```*!QV@XP0`H.$S\__K
M`3"`XA$`4.,!`%,3)```BO@@G^6P,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C&@``&@C0C>)P@+WH!`"5Y:[]_^L``%#C`$"@X0@`A>7G__\:N`"?Y0``
MC^"<\__K`3#0Y0``4^.:__\*E?__ZJ`PG^4!`*#A`S"/X`0PD^4`$)/EYOC_
MZ[W__^J(,)_E`S"?YP,`E.=R\__KHO__ZGGS_^MT()_E`#"@X0(@C^`$$)+E
M:`"?Y00@H.$`$)'E``"/X(+S_^LT9P``'`$``!QH``!4"```X&<``.`)``"L
M9P``O`D``'QG``"0"0``4`<``#AG```D9P``0`D``$0)``#L9@``T`8``$!G
M``",90``H`@``*QF```@9@``>&8``%P(```!RJ#C,$`MZ0S`3>#H#XSE#"&?
MY0PQG^4"((_@`$"@X00!G^4#,)+G#-!-X@T0H.$``(_@`#"3Y00PC>4`,*#C
MO??_ZP`P4.(*```*`##3Y3``4^,``%,3`3"@`P`PH!,!,"/B``!4XP`PH`,!
M,`,2``!3XPH``!JP()_EI#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XR``
M`!H,T(WB,("]Z``PU.4``%/C\?__"@0`H.%_^O_K+Q"@XP!0H.'?\O_K``!0
MXP%0@!(%`*#A%_/_ZU@0G^4$(*#C`1"/X$/S_^L``%#CXO__&D0@G^4P,)_E
M`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`P``&@0`H.$,T(WB,$"]Z.GW_^H/
M\__K9&0``!P!``"X!0``_&,``-0%``"(8P```<J@XQ!`+>D,P$W@^`^,Y8``
MH.,`\__K#WN?[0![@.T/>Y_M`GN`[0][G^T$>X#M#WN?[09[@.T/>Y_M`""@
MXPA[@.T.>Y_M>""`Y0I[@.T,>X#M$("]Z`#P(.,!(T5G`````(FKS>\`````
M_MRZF`````!V5#(0`````/#ATL,````````````````!RJ#C\$<MZ0S`3>#@
M#XSE`F"@X0`PH.,!<*#A*!"0Y2P@D.6&P8'@`0!<X0(@T^``4*#A,""0Y300
MD.7&#Z#A`0``*@$@DN(`$*'B+#"%Y:8^H.&`,8/A`C"3X*`>H>!X`)7E*,"%
MY0``4.,P,(7E-!"%Y3B@A0(E```:/P!6XQT``-H'0*#A)H.@X4"01N(!8$CB
M"(.'X`0PH.$*(*#A0!"$X@!`D^4$X)/E","3Y0P`D^40,(/B`0!3X0!`@N4$
MX(+E",""Y0P`@N40((+B\___&@-`H.$%`*#A`_3_ZP@`5.'K__\:!FUFX$!P
MA^(&8XG@/Y#)XP=PB>`&(*#A!Q"@X0H`H.&"\O_K>&"%Y?"'O>A`0&#B!@!4
MX09`H*$XH(7B!Q"@X00@H.$``(K@>/+_ZW@PE>4#,(3@0`!3XW@PA>7PA[T8
M!0"@X01@1N`$<(?@Y?/_Z\?__^H!RJ#C\$$MZ0S`3>#H#XSE?\#@XR@PD>4P
M8)'E,W^_YJ,QH.$_,`/B`2"#XCB`@>(X`%+C`%"@X0%`H.$V;[_F`\#(YP(`
MB.`[``#:`!"@XT`@8N(K\O_K!`"@X<SS_^LX(*#C`!"@XP@`H.$E\O_K!`"@
MX?!GQ.'%\__K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E
M`S#%Y0LPU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(
M,,7ELC'4X0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TP
MQ>48,)3E(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@
MX1(PQ>4@,)3E$S#%Y?!!O>@!\O_J`!"@XS@@8N+O\?_KR/__Z@@PG^4#,(_@
M`#"3Y4?R_^I`80``"$`MZ0B`O>@!``(`0`````D````P````"0````0````)
M````#`````D````_````"0```#<````)````%P````D````O````"0```!$`
M```)````,P````D````5````"0```!(````)````'P````D````V````"0``
M`!`````)````)`````D````J````"0``````````````)7,O)7,```!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M````+W!R;V,O<V5L9B]E>&4``"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%
M35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)
M0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#
M04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(`
M``!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@`````Q````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D`$Q$7TQ)0E)!
M4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D```E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U
M)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].````
M`#$N,#8S````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"10
M05)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE
M*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O
M9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ
M92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I
M;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D
M<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@
M("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*
M=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D
M9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR
M971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M
M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*
M;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB
M+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N
M86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM
M>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B![
M"DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P
M<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T
M<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY
M("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC
M7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B
M)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#
M.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?
M<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U
M9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD
M(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B
M(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*
M;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@
M9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD
M<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O
M(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O
M.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M
M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O
M+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L
M("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE
M(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I
M<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@
M9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D
M;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY
M("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H
M)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E
M9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N
M+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T
M:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D
M;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP
M<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P
M<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@
M1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M
M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[
M8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@
M*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(
M02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I
M.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C
M86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE
M7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN
M97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII
M<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D[
M"B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C
M=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y
M<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@
M9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC
M7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B
M*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM
M("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C
M:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$[
M"GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N
M("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT
M96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L
M:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,
M7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH`55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP
M`````'!E<FQX<VDN8P````!#04-(10``0`````D````P````"0````0````)
M````#`````D````_````"0```#<````)````%P````D````O````"0```!$`
M```)````,P````D````5````"0```!(````)````'P````D````V````"0``
M`!`````)````)`````D````J````"0``````````````@;(!@;"PK`<`````
MAK(!@;"PJP\`````H+(!@;"PKP<`````@;(!@;"PJ@<`````A`(!@;`/L0``
M````AK(!@;"PK7\`````K(?_?["J"8!LBO]_`0```-R+_W^O)K*`6)C_?["P
MKH`LF?]_L*@;@-29_W^PJQZ`5)O_?["H`X#XF_]_?/__?RB=_W^PKP*`;)__
M?["P`8"\G_]_</__?]"@_W^PL+"`S*#_?VS__W]4H_]_L+"H@'RC_W]H__]_
M(*7_?["J`8!<JO]_`(0"@/2J_W]<__]_8*O_?V#__W\8K?]_L+"H@#2M_W^P
MJP:`9*[_?["O/H"TM?]_L*H!@'RX_W^PJ0*`L+G_?["PJ(`TNO]_L+"N@(B[
M_W^PL*R`S+S_?["PL(#8O/]_`0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````^!P``(0<```!
M````2P,```$```!6`P```0```&`#```!````=`,``!T```#\!```#````-`5
M```-````S$X``!D```"DK0``&P````0````:````J*T``!P````$````!```
M`+0!``#U_O]O[`0```4```"(#```!@```-@%```*````-P4```L````0````
M%0`````````#````S*X```(```#@`0``%````!$````7````\!,``!$````8
M$P``$@```-@````3````"````!X````(````^___;P$```C^__]OF!(``/__
M_V\#````\/__;\`1``#Z__]O#@``````````````````````````````````
M``````````````````````"LK0````````````#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<
M%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5
M``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4`
M`-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``
MW!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5``#<%0``W!4``-P5````
M````````````````````````````````````````````````````````````
M````````P!@````````$L```"E!!4BYP;0H`````()```,1/````````A%``
M`(A0```4D```S$\``!R0`````````)````B0````````D%(``$=#0SH@*%-5
M4T4@3&EN=7@I(#$T+C(N,2`R,#(U,#(R,"!;<F5V:7-I;VX@.69F96-D93$R
M,6%F.#@S8C8P8F)E-C!D,#`T,C4P,S9B8S@W,S`T.%T`03(```!A96%B:0`!
M*`````4V2UH`!@<(`0D!"@(2!!,!%`$5`1<#&`$9`1H"'`$B`40!`"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+D%232YE>'1A8@`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
M```````````````````````````````+`````0````(```!4`0``5`$``!D`
M``````````````$`````````$P````<````"````<`$``'`!```D````````
M```````$`````````"8````'`````@```)0!``"4`0``(```````````````
M!``````````X````!0````(```"T`0``M`$``#@#```&``````````0````$
M````-````/;__V\"````[`0``.P$``#L````!@`````````$````!````#X`
M```+`````@```-@%``#8!0``L`8```<````#````!````!````!&`````P``
M``(```"(#```B`P``#<%``````````````$`````````3@```/___V\"````
MP!$``,`1``#6````!@`````````"`````@```%L```#^__]O`@```)@2``"8
M$@``@`````<````#````!`````````!J````"0````(````8$P``&!,``-@`
M```&``````````0````(````<P````D```!"````\!,``/`3``#@`0``!@``
M`!<````$````"````'P````!````!@```-`5``#0%0``#```````````````
M!`````````!W`````0````8```#<%0``W!4``.0"``````````````0````$
M````@@````$````&````P!@``,`8```,-@`````````````(`````````(@`
M```!````!@```,Q.``#,3@``"```````````````!`````````".`````0``
M``(```#43@``U$X``/A!``````````````0`````````E@````$````"````
MS)```,R0``!(```````````````$`````````*$````!``!P@@```!21```4
MD0``Z`````X`````````!`````````"L`````0````(```#\D0``_)$```0`
M``````````````0`````````M@````X````#````I*T``*2=```$````````
M```````$````!````,(````/`````P```*BM``"HG0``!```````````````
M!`````0```#.````!@````,```"LK0``K)T``"`!```'``````````0````(
M````UP````$````#````S*X``,R>```T`0`````````````$````!````-P`
M```!`````P````"P````H```2```````````````!`````````#B````"```
M``,```!(L```2*```!0```````````````0`````````YP````$````P````
M`````$B@``!6```````````````!`````0```/`````#``!P``````````">
MH```,P```````````````0`````````!`````P``````````````T:`````!
2``````````````$`````````
